@@ -1,47 +1,41 @@
+=begin
 #
-# benchmark.rb - a performance benchmarking library 
-# 
-# $Id: benchmark.rb,v 1.8 2003/09/19 06:39:07 gsinclair Exp $
-# 
-# Created by Gotoken (gotoken@notwork.org). 
+# benchmark.rb - a performance benchmarking library
+#
+# $Id: benchmark.rb 31511 2011-05-11 21:23:27Z yugui $
+#
+# Created by Gotoken (gotoken@notwork.org).
 #
 # Documentation by Gotoken (original RD), Lyle Johnson (RDoc conversion), and
-# Gavin Sinclair (editing). 
+# Gavin Sinclair (editing).
 #
+=end
+
 # == Overview
 #
 # The Benchmark module provides methods for benchmarking Ruby code, giving
 # detailed reports on the time taken for each task.
 #
 
-
-#
 # The Benchmark module provides methods to measure and report the time
-# used to execute Ruby code.  Read on for illustrative examples.
-# 
-# == Examples
-# 
+# used to execute Ruby code.
 #
-# === Example 1
-#
-# To measure the time to construct the string given by the expression
-# <tt>"a"*1_000_000</tt>:
+# * Measure the time to construct the string given by the expression
+#   <tt>"a"*1_000_000</tt>:
 #
 #       require 'benchmark'
 #
 #       puts Benchmark.measure { "a"*1_000_000 }
-# 
-# On my machine (FreeBSD 3.2 on P5100MHz) this reported as follows:
-# 
+#
+#   On my machine (FreeBSD 3.2 on P5, 100MHz) this generates:
+#
 #       1.166667   0.050000   1.216667 (  0.571355)
-# 
-# This report shows the user CPU time, system CPU time, the sum of the user and
-# system CPU times, and the elapsed real time. The unit of time is seconds.
-# 
 #
-# === Example 2
+#   This report shows the user CPU time, system CPU time, the sum of
+#   the user and system CPU times, and the elapsed real time. The unit
+#   of time is seconds.
 #
-# To do some experiments sequentially, the #bm method is useful:
+# * Do some experiments sequentially using the #bm method:
 #
 #       require 'benchmark'
 #
@@ -51,18 +45,15 @@
 #         x.report { n.times do   ; a = "1"; end }
 #         x.report { 1.upto(n) do ; a = "1"; end }
 #       end
-# 
-# The result:
+#
+#   The result:
 #
 #              user     system      total        real
 #          1.033333   0.016667   1.016667 (  0.492106)
 #          1.483333   0.000000   1.483333 (  0.694605)
 #          1.516667   0.000000   1.516667 (  0.711077)
 #
-#
-# === Example 3
-#
-# Continuing the previous example, to put a label in each report:
+# * Continuing the previous example, put a label in each report:
 #
 #       require 'benchmark'
 #
@@ -72,54 +63,47 @@
 #         x.report("times:") { n.times do   ; a = "1"; end }
 #         x.report("upto:")  { 1.upto(n) do ; a = "1"; end }
 #       end
-# 
-# The argument to #bm (7) specifies the offset of each report according to the
-# longest label.
-# 
+#
 # The result:
-# 
+#
 #                     user     system      total        real
 #        for:     1.050000   0.000000   1.050000 (  0.503462)
 #        times:   1.533333   0.016667   1.550000 (  0.735473)
 #        upto:    1.500000   0.016667   1.516667 (  0.711239)
-# 
 #
-# === Example 4
-# 
-# The times for some benchmarks depend on the order in which items are run.
-# These differences are due to the cost of memory allocation and garbage
-# collection.
 #
-# To avoid these discrepancies, the #bmbm method is provided.  For example, to
-# compare ways for sort an array of floats:
+# * The times for some benchmarks depend on the order in which items
+#   are run.  These differences are due to the cost of memory
+#   allocation and garbage collection. To avoid these discrepancies,
+#   the #bmbm method is provided.  For example, to compare ways to
+#   sort an array of floats:
 #
 #       require 'benchmark'
-#       
+#
 #       array = (1..1000000).map { rand }
-#       
+#
 #       Benchmark.bmbm do |x|
 #         x.report("sort!") { array.dup.sort! }
 #         x.report("sort")  { array.dup.sort  }
 #       end
-# 
-# The result:
-# 
+#
+#   The result:
+#
 #        Rehearsal -----------------------------------------
 #        sort!  11.928000   0.010000  11.938000 ( 12.756000)
 #        sort   13.048000   0.020000  13.068000 ( 13.857000)
 #        ------------------------------- total: 25.006000sec
-#        
+#
 #                    user     system      total        real
 #        sort!  12.959000   0.010000  12.969000 ( 13.793000)
 #        sort   12.007000   0.000000  12.007000 ( 12.791000)
 #
 #
-# === Example 5
-#
-# To report statistics of sequential experiments with unique labels,
-# #benchmark is available:
+# * Report statistics of sequential experiments with unique labels,
+#   using the #benchmark method:
 #
 #       require 'benchmark'
+#       include Benchmark         # we need the CAPTION and FMTSTR constants
 #
 #       n = 50000
 #       Benchmark.benchmark(" "*7 + CAPTION, 7, FMTSTR, ">total:", ">avg:") do |x|
@@ -128,38 +112,43 @@
 #         tu = x.report("upto:")  { 1.upto(n) do ; a = "1"; end }
 #         [tf+tt+tu, (tf+tt+tu)/3]
 #       end
-# 
-# The result:
-# 
+#
+#   The result:
+#
 #                     user     system      total        real
 #        for:     1.016667   0.016667   1.033333 (  0.485749)
 #        times:   1.450000   0.016667   1.466667 (  0.681367)
 #        upto:    1.533333   0.000000   1.533333 (  0.722166)
 #        >total:  4.000000   0.033333   4.033333 (  1.889282)
 #        >avg:    1.333333   0.011111   1.344444 (  0.629761)
-# 
+
 module Benchmark
 
-  # BENCHMARK_VERSION is version string containing the last modification
-  # date (YYYY-MM-DD). 
-  BENCHMARK_VERSION = "2002-04-25"
+  BENCHMARK_VERSION = "2002-04-25" #:nodoc"
 
   def Benchmark::times() # :nodoc:
       Process::times()
   end
 
 
-  #
-  # Reports the time required to execute one or more blocks of code.
+  # Invokes the block with a <tt>Benchmark::Report</tt> object, which
+  # may be used to collect and report on the results of individual
+  # benchmark tests. Reserves <i>label_width</i> leading spaces for
+  # labels on each line. Prints _caption_ at the top of the
+  # report, and uses _fmt_ to format each line.
+  # If the block returns an array of
+  # <tt>Benchmark::Tms</tt> objects, these will be used to format
+  # additional lines of output. If _label_ parameters are
+  # given, these are used to label these extra lines.
   #
   # _Note_: Other methods provide a simpler interface to this one, and are
   # suitable for nearly all benchmarking requirements.  See the examples in
   # Benchmark, and the #bm and #bmbm methods.
   #
-  # Example: 
+  # Example:
   #
   #     require 'benchmark'
-  #     include Benchmark          # we need the CAPTION and FMTSTR constants 
+  #     include Benchmark          # we need the CAPTION and FMTSTR constants
   #
   #     n = 50000
   #     Benchmark.benchmark(" "*7 + CAPTION, 7, FMTSTR, ">total:", ">avg:") do |x|
@@ -168,33 +157,17 @@ module Benchmark
   #       tu = x.report("upto:")  { 1.upto(n) do ; a = "1"; end }
   #       [tf+tt+tu, (tf+tt+tu)/3]
   #     end
-  # 
-  # The result:
-  # 
+  #
+  # <i>Generates:</i>
+  #
   #                     user     system      total        real
   #        for:     1.016667   0.016667   1.033333 (  0.485749)
   #        times:   1.450000   0.016667   1.466667 (  0.681367)
   #        upto:    1.533333   0.000000   1.533333 (  0.722166)
   #        >total:  4.000000   0.033333   4.033333 (  1.889282)
   #        >avg:    1.333333   0.011111   1.344444 (  0.629761)
-  # 
-  # The parameters accepted are as follows:
-  # 
-  # _caption_::
-  #   A string printed once before execution of the given block. 
-  # 
-  # _label_width_::
-  #   An integer used as an offset in each report. 
-  # 
-  # _fmtstr_::
-  #   A string used to format each measurement. See Benchmark::Tms#format.
-  # 
-  # _labels_::
-  #   The remaining parameters are used as prefix of the format to the
-  #   value of block; see the example above.
   #
-  # This method yields a Benchmark::Report object. 
-  # 
+
   def benchmark(caption = "", label_width = nil, fmtstr = nil, *labels) # :yield: report
     sync = STDOUT.sync
     STDOUT.sync = true
@@ -204,17 +177,16 @@ module Benchmark
     print caption
     results = yield(Report.new(label_width, fmtstr))
     Array === results and results.grep(Tms).each {|t|
-      print((labels.shift || t.label || "").ljust(label_width), 
+      print((labels.shift || t.label || "").ljust(label_width),
             t.format(fmtstr))
     }
     STDOUT.sync = sync
   end
 
 
-  # 
-  # A simple interface to #benchmark, #bm is suitable for sequential reports
-  # with labels.  For example:
-  # 
+  # A simple interface to the #benchmark method, #bm is generates sequential reports
+  # with labels.  The parameters have the same meaning as for #benchmark.
+  #
   #     require 'benchmark'
   #
   #     n = 50000
@@ -223,61 +195,55 @@ module Benchmark
   #       x.report("times:") { n.times do   ; a = "1"; end }
   #       x.report("upto:")  { 1.upto(n) do ; a = "1"; end }
   #     end
-  # 
-  # The argument to #bm (7) specifies the offset of each report according to the
-  # longest label.
-  # 
-  # This reports as follows:
-  # 
+  #
+  # <i>Generates:</i>
+  #
   #                     user     system      total        real
   #        for:     1.050000   0.000000   1.050000 (  0.503462)
   #        times:   1.533333   0.016667   1.550000 (  0.735473)
   #        upto:    1.500000   0.016667   1.516667 (  0.711239)
   #
-  # The labels are optional. 
-  # 
+
   def bm(label_width = 0, *labels, &blk) # :yield: report
     benchmark(" "*label_width + CAPTION, label_width, FMTSTR, *labels, &blk)
   end
 
 
-  # 
-  # Similar to #bm, but designed to prevent memory allocation and garbage
-  # collection from influencing the result.  It works like this:
-  # 
-  # 1. The _rehearsal_ step runs all items in the job list to allocate
-  #    enough memory.
-  # 2. Before each measurement, invokes GC.start to prevent the influence of
-  #    previous job. 
+  # Sometimes benchmark results are skewed because code executed
+  # earlier encounters different garbage collection overheads than
+  # that run later. #bmbm attempts to minimize this effect by running
+  # the tests twice, the first time as a rehearsal in order to get the
+  # runtime environment stable, the second time for
+  # real. <tt>GC.start</tt> is executed before the start of each of
+  # the real timings; the cost of this is not included in the
+  # timings. In reality, though, there's only so much that #bmbm can
+  # do, and the results are not guaranteed to be isolated from garbage
+  # collection and other effects.
   #
-  # If the specified _label_width_ is less than the width of the widest label
-  # passed as an argument to #item, the latter is used.  (Because #bmbm is a
-  # 2-pass procedure, this is possible.)  Therefore you do not really need to
-  # specify a label width.
-  #
-  # For example:
+  # Because #bmbm takes two passes through the tests, it can
+  # calculate the required label width.
   #
   #       require 'benchmark'
-  #       
+  #
   #       array = (1..1000000).map { rand }
-  #       
+  #
   #       Benchmark.bmbm do |x|
   #         x.report("sort!") { array.dup.sort! }
   #         x.report("sort")  { array.dup.sort  }
   #       end
-  # 
-  # The result:
-  # 
+  #
+  # <i>Generates:</i>
+  #
   #        Rehearsal -----------------------------------------
   #        sort!  11.928000   0.010000  11.938000 ( 12.756000)
   #        sort   13.048000   0.020000  13.068000 ( 13.857000)
   #        ------------------------------- total: 25.006000sec
-  #        
+  #
   #                    user     system      total        real
   #        sort!  12.959000   0.010000  12.969000 ( 13.793000)
   #        sort   12.007000   0.000000  12.007000 ( 12.791000)
   #
-  # #bmbm yields a Benchmark::Job object and returns an array of one
+  # #bmbm yields a Benchmark::Job object and returns an array of
   # Benchmark::Tms objects.
   #
   def bmbm(width = 0, &blk) # :yield: job
@@ -301,7 +267,7 @@ module Benchmark
     ets = sum.format("total: %tsec")
     printf("%s %s\n\n",
            "-"*(width+CAPTION.length-ets.length-1), ets)
-    
+
     # take
     print ' '*width, CAPTION
     list = []
@@ -315,11 +281,12 @@ module Benchmark
       list.push [label, res]
     }
 
-    STDOUT.sync = sync
     ary
+  ensure
+    STDOUT.sync = sync unless sync.nil?
   end
 
-  # 
+  #
   # Returns the time used to execute the given block as a
   # Benchmark::Tms object.
   #
@@ -327,10 +294,10 @@ module Benchmark
     t0, r0 = Benchmark.times, Time.now
     yield
     t1, r1 = Benchmark.times, Time.now
-    Benchmark::Tms.new(t1.utime  - t0.utime, 
-                       t1.stime  - t0.stime, 
-                       t1.cutime - t0.cutime, 
-                       t1.cstime - t0.cstime, 
+    Benchmark::Tms.new(t1.utime  - t0.utime,
+                       t1.stime  - t0.stime,
+                       t1.cutime - t0.cutime,
+                       t1.cstime - t0.cstime,
                        r1.to_f - r0.to_f,
                        label)
   end
@@ -339,7 +306,10 @@ module Benchmark
   # Returns the elapsed real time used to execute the given block.
   #
   def realtime(&blk) # :yield:
-    Benchmark::measure(&blk).real
+    r0 = Time.now
+    yield
+    r1 = Time.now
+    r1.to_f - r0.to_f
   end
 
 
@@ -348,14 +318,14 @@ module Benchmark
   # A Job is a sequence of labelled blocks to be processed by the
   # Benchmark.bmbm method.  It is of little direct interest to the user.
   #
-  class Job
+  class Job # :nodoc:
     #
     # Returns an initialized Job instance.
     # Usually, one doesn't call this method directly, as new
     # Job objects are created by the #bmbm method.
     # _width_ is a initial value for the label offset used in formatting;
-    # the #bmbm method passes its _width_ argument to this constructor. 
-    # 
+    # the #bmbm method passes its _width_ argument to this constructor.
+    #
     def initialize(width)
       @width = width
       @list = []
@@ -365,8 +335,8 @@ module Benchmark
     # Registers the given label and block pair in the job list.
     #
     def item(label = "", &blk) # :yield:
-      raise ArgmentError, "no block" unless block_given?
-      label.concat ' '
+      raise ArgumentError, "no block" unless block_given?
+      label += ' '
       w = label.length
       @width = w if @width < w
       @list.push [label, blk]
@@ -374,11 +344,11 @@ module Benchmark
     end
 
     alias report item
-    
+
     # An array of 2-element arrays, consisting of label and block pairs.
     attr_reader :list
-    
-    # Length of the widest label in the #list, plus one.  
+
+    # Length of the widest label in the #list, plus one.
     attr_reader :width
   end
 
@@ -390,14 +360,14 @@ module Benchmark
   # This class is used by the Benchmark.benchmark and Benchmark.bm methods.
   # It is of little direct interest to the user.
   #
-  class Report
+  class Report # :nodoc:
     #
     # Returns an initialized Report instance.
     # Usually, one doesn't call this method directly, as new
-    # Report objects are created by the #benchmark and #bm methods. 
-    # _width_ and _fmtstr_ are the label offset and 
-    # format string used by Tms#format. 
-    # 
+    # Report objects are created by the #benchmark and #bm methods.
+    # _width_ and _fmtstr_ are the label offset and
+    # format string used by Tms#format.
+    #
     def initialize(width = 0, fmtstr = nil)
       @width, @fmtstr = width, fmtstr
     end
@@ -429,50 +399,50 @@ module Benchmark
 
     # User CPU time
     attr_reader :utime
-    
+
     # System CPU time
     attr_reader :stime
-   
+
     # User CPU time of children
     attr_reader :cutime
-    
+
     # System CPU time of children
     attr_reader :cstime
-    
+
     # Elapsed real time
     attr_reader :real
-    
-    # Total time, that is _utime_ + _stime_ + _cutime_ + _cstime_ 
+
+    # Total time, that is _utime_ + _stime_ + _cutime_ + _cstime_
     attr_reader :total
-    
+
     # Label
     attr_reader :label
 
     #
-    # Returns a initialized Tms object which has
-    # _u_ as the user CPU time, _s_ as the system CPU time, 
-    # _cu_ as the childrens' user CPU time, _cs_ as the childrens'
+    # Returns an initialized Tms object which has
+    # _u_ as the user CPU time, _s_ as the system CPU time,
+    # _cu_ as the children's user CPU time, _cs_ as the children's
     # system CPU time, _real_ as the elapsed real time and _l_
-    # as the label. 
-    # 
+    # as the label.
+    #
     def initialize(u = 0.0, s = 0.0, cu = 0.0, cs = 0.0, real = 0.0, l = nil)
       @utime, @stime, @cutime, @cstime, @real, @label = u, s, cu, cs, real, l
       @total = @utime + @stime + @cutime + @cstime
     end
 
-    # 
+    #
     # Returns a new Tms object whose times are the sum of the times for this
     # Tms object, plus the time required to execute the code block (_blk_).
-    # 
+    #
     def add(&blk) # :yield:
-      self + Benchmark::measure(&blk) 
+      self + Benchmark::measure(&blk)
     end
 
-    # 
+    #
     # An in-place version of #add.
-    # 
-    def add!
-      t = Benchmark::measure(&blk) 
+    #
+    def add!(&blk)
+      t = Benchmark::measure(&blk)
       @utime  = utime + t.utime
       @stime  = stime + t.stime
       @cutime = cutime + t.cutime
@@ -481,32 +451,32 @@ module Benchmark
       self
     end
 
-    # 
+    #
     # Returns a new Tms object obtained by memberwise summation
     # of the individual times for this Tms object with those of the other
     # Tms object.
-    # This method and #/() are useful for taking statistics. 
-    # 
+    # This method and #/() are useful for taking statistics.
+    #
     def +(other); memberwise(:+, other) end
-    
+
     #
     # Returns a new Tms object obtained by memberwise subtraction
     # of the individual times for the other Tms object from those of this
     # Tms object.
     #
     def -(other); memberwise(:-, other) end
-    
+
     #
     # Returns a new Tms object obtained by memberwise multiplication
     # of the individual times for this Tms object by _x_.
     #
     def *(x); memberwise(:*, x) end
 
-    # 
+    #
     # Returns a new Tms object obtained by memberwise division
     # of the individual times for this Tms object by _x_.
-    # This method and #+() are useful for taking statistics. 
-    # 
+    # This method and #+() are useful for taking statistics.
+    #
     def /(x); memberwise(:/, x) end
 
     #
@@ -517,15 +487,15 @@ module Benchmark
     #
     # <tt>%u</tt>::     Replaced by the user CPU time, as reported by Tms#utime.
     # <tt>%y</tt>::     Replaced by the system CPU time, as reported by #stime (Mnemonic: y of "s*y*stem")
-    # <tt>%U</tt>::     Replaced by the childrens' user CPU time, as reported by Tms#cutime 
-    # <tt>%Y</tt>::     Replaced by the childrens' system CPU time, as reported by Tms#cstime
+    # <tt>%U</tt>::     Replaced by the children's user CPU time, as reported by Tms#cutime
+    # <tt>%Y</tt>::     Replaced by the children's system CPU time, as reported by Tms#cstime
     # <tt>%t</tt>::     Replaced by the total CPU time, as reported by Tms#total
     # <tt>%r</tt>::     Replaced by the elapsed real time, as reported by Tms#real
     # <tt>%n</tt>::     Replaced by the label string, as reported by Tms#label (Mnemonic: n of "*n*ame")
-    # 
+    #
     # If _fmtstr_ is not given, FMTSTR is used as default value, detailing the
     # user, system and real elapsed time.
-    # 
+    #
     def format(arg0 = nil, *args)
       fmtstr = (arg0 || FMTSTR).dup
       fmtstr.gsub!(/(%[-+\.\d]*)n/){"#{$1}s" % label}
@@ -538,19 +508,19 @@ module Benchmark
       arg0 ? Kernel::format(fmtstr, *args) : fmtstr
     end
 
-    # 
+    #
     # Same as #format.
-    # 
+    #
     def to_s
       format
     end
 
-    # 
+    #
     # Returns a new 6-element array, consisting of the
-    # label, user CPU time, system CPU time, childrens'
-    # user CPU time, childrens' system CPU time and elapsed
+    # label, user CPU time, system CPU time, children's
+    # user CPU time, children's system CPU time and elapsed
     # real time.
-    # 
+    #
     def to_a
       [@label, @utime, @stime, @cutime, @cstime, @real]
     end
@@ -579,7 +549,7 @@ module Benchmark
   # The default caption string (heading above the output times).
   CAPTION = Benchmark::Tms::CAPTION
 
-  # The default format string used to display times.  See also Benchmark::Tms#format. 
+  # The default format string used to display times.  See also Benchmark::Tms#format.
   FMTSTR = Benchmark::Tms::FMTSTR
 end
 
