@@ -2,29 +2,44 @@
 # This file was created by mkconfig.rb when ruby was built.  Any
 # changes made to this file will be lost the next time ruby is built.
 
-module Config
-  RUBY_VERSION == "1.8.7" or
-    raise "ruby lib version (1.8.7) doesn't match executable version (#{RUBY_VERSION})"
+module RbConfig
+  RUBY_VERSION == "1.9.2" or
+    raise "ruby lib version (1.9.2) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.8/hppa-openbsd")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.9.1/hppa-openbsd")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
-  CONFIG["PATCHLEVEL"] = "374"
+  CONFIG["MAJOR"] = "1"
+  CONFIG["MINOR"] = "9"
+  CONFIG["TEENY"] = "1"
+  CONFIG["PATCHLEVEL"] = "290"
   CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
-  CONFIG["ruby_install_name"] = "ruby18"
-  CONFIG["RUBY_INSTALL_NAME"] = "ruby18"
-  CONFIG["RUBY_SO_NAME"] = "ruby18"
-  CONFIG["MANTYPE"] = "man"
-  CONFIG["NROFF"] = "/bin/false"
-  CONFIG["configure_args"] = " '--program-suffix=18' '--enable-ipv6' '--with-dbm-type=bogus' '--with-opt-dir=/usr/local' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'YACC=yacc'"
-  CONFIG["vendordir"] = "$(libdir)/ruby/vendor_ruby"
-  CONFIG["sitedir"] = "$(libdir)/ruby/site_ruby"
-  CONFIG["sitearch"] = "hppa-openbsd"
+  CONFIG["ruby_install_name"] = "ruby19"
+  CONFIG["RUBY_INSTALL_NAME"] = "ruby19"
+  CONFIG["RUBY_SO_NAME"] = "ruby19"
+  CONFIG["PACKAGE"] = "ruby"
+  CONFIG["BUILTIN_TRANSSRCS"] = " newline.c"
+  CONFIG["MANTYPE"] = "doc"
+  CONFIG["NROFF"] = "/usr/bin/nroff"
+  CONFIG["vendorhdrdir"] = "$(rubyhdrdir)/vendor_ruby"
+  CONFIG["sitehdrdir"] = "$(rubyhdrdir)/site_ruby"
+  CONFIG["rubyhdrdir"] = "$(includedir)/$(RUBY_BASE_NAME)-$(ruby_version)"
+  CONFIG["UNIVERSAL_INTS"] = ""
+  CONFIG["UNIVERSAL_ARCHNAMES"] = ""
+  CONFIG["configure_args"] = " '--program-suffix=19' '--with-soname=ruby19' '--enable-pthread' '--enable-ipv6' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
+  CONFIG["vendordir"] = "$(rubylibprefix)/vendor_ruby"
+  CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
+  CONFIG["ruby_version"] = "1.9.1"
+  CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "hppa-openbsd"
+  CONFIG["RI_BASE_NAME"] = "ri"
+  CONFIG["ridir"] = "$(datarootdir)/$(RI_BASE_NAME)"
+  CONFIG["rubylibprefix"] = "$(libdir)/$(RUBY_BASE_NAME)"
   CONFIG["MAKEFILES"] = "Makefile"
+  CONFIG["THREAD_MODEL"] = "pthread"
   CONFIG["EXPORT_PREFIX"] = ""
   CONFIG["COMMON_HEADERS"] = ""
   CONFIG["COMMON_MACROS"] = ""
@@ -34,7 +49,7 @@ module Config
   CONFIG["DLDLIBS"] = " -lc"
   CONFIG["SOLIBS"] = "$(LIBS)"
   CONFIG["LIBRUBYARG_SHARED"] = "-Wl,-R -Wl,$(libdir) -L$(libdir) -l$(RUBY_SO_NAME)"
-  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static"
+  CONFIG["LIBRUBYARG_STATIC"] = "-Wl,-R -Wl,$(libdir) -L$(libdir) -l$(RUBY_SO_NAME)-static"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
@@ -43,15 +58,20 @@ module Config
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
-  CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -shared  -fPIC"
-  CONFIG["debugflags"] = ""
-  CONFIG["optflags"] = ""
-  CONFIG["cflags"] = "$(optflags) $(debugflags)"
+  CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -shared $(CCDLFLAGS)"
+  CONFIG["warnflags"] = "-Wextra -Wno-unused-parameter -Wno-parentheses -Wpointer-arith -Wwrite-strings -Wno-missing-field-initializers -Wno-long-long"
+  CONFIG["debugflags"] = "-g"
+  CONFIG["optflags"] = "-O3"
+  CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cflags"] = " $(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include"
-  CONFIG["RDOCTARGET"] = ""
+  CONFIG["INSTALLDOC"] = "all"
+  CONFIG["RDOCTARGET"] = "rdoc"
+  CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["EXTOUT"] = ".ext"
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
+  CONFIG["TEST_RUNNABLE"] = "yes"
   CONFIG["setup"] = "Setup"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["STRIP"] = "strip"
@@ -63,60 +83,74 @@ module Config
   CONFIG["LIBEXT"] = "a"
   CONFIG["DLEXT2"] = ""
   CONFIG["DLEXT"] = "so"
-  CONFIG["LDSHARED"] = "$(CC) -shared  -fPIC"
-  CONFIG["CCDLFLAGS"] = " -fPIC"
+  CONFIG["LDSHAREDXX"] = "$(CXX) -shared $(CCDLFLAGS)"
+  CONFIG["LDSHARED"] = "$(CC) -shared $(CCDLFLAGS)"
+  CONFIG["CCDLFLAGS"] = "-fPIC"
   CONFIG["STATIC"] = ""
   CONFIG["ARCH_FLAG"] = ""
   CONFIG["DLDFLAGS"] = ""
   CONFIG["ALLOCA"] = ""
-  CONFIG["MAKEDIRS"] = "mkdir -p"
+  CONFIG["CHDIR"] = "cd -P"
+  CONFIG["RMALL"] = "rm -fr"
+  CONFIG["RMDIRS"] = "$(top_srcdir)/tool/rmdirs"
   CONFIG["CP"] = "cp"
   CONFIG["RM"] = "rm -f"
+  CONFIG["CAPITARGET"] = "nodoc"
+  CONFIG["DOXYGEN"] = ""
+  CONFIG["DOT"] = ""
+  CONFIG["MAKEDIRS"] = "mkdir -p"
+  CONFIG["MKDIR_P"] = "mkdir -p"
   CONFIG["INSTALL_DATA"] = "install -c -o root -g bin -m 444"
   CONFIG["INSTALL_SCRIPT"] = "install -c -o root -g bin -m 555"
   CONFIG["INSTALL_PROGRAM"] = "install -c -s -o root -g bin -m 555"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
-  CONFIG["OBJDUMP"] = ""
   CONFIG["DLLWRAP"] = ""
   CONFIG["WINDRES"] = ""
   CONFIG["NM"] = ""
+  CONFIG["OBJCOPY"] = "objcopy"
+  CONFIG["OBJDUMP"] = "objdump"
   CONFIG["ASFLAGS"] = ""
   CONFIG["AS"] = "as"
   CONFIG["AR"] = "ar"
   CONFIG["RANLIB"] = "ranlib"
-  CONFIG["YFLAGS"] = ""
-  CONFIG["YACC"] = "yacc"
+  CONFIG["try_header"] = ""
+  CONFIG["COUTFLAG"] = "-o "
   CONFIG["OUTFLAG"] = "-o "
   CONFIG["CPPOUTFILE"] = "-o conftest.i"
   CONFIG["GNU_LD"] = "yes"
-  CONFIG["EGREP"] = "/usr/bin/egrep"
-  CONFIG["GREP"] = "/usr/bin/grep"
-  CONFIG["CPP"] = "cc -E"
+  CONFIG["GCC"] = "yes"
+  CONFIG["EGREP"] = "/usr/local/bin/ggrep -E"
+  CONFIG["GREP"] = "/usr/local/bin/ggrep"
+  CONFIG["CPP"] = "$(CC) -E"
+  CONFIG["CXXFLAGS"] = "-O2 -pipe"
+  CONFIG["CXX"] = "c++"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -Wl,-E"
-  CONFIG["CFLAGS"] = "-O2 -pipe  -fPIC $(cflags)"
+  CONFIG["CFLAGS"] = "-O2 -pipe -fPIC"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd5.4"
+  CONFIG["target_os"] = "openbsd5.0"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "hppa"
-  CONFIG["target"] = "hppa-unknown-openbsd5.4"
-  CONFIG["host_os"] = "openbsd5.4"
+  CONFIG["target"] = "hppa-unknown-openbsd5.0"
+  CONFIG["host_os"] = "openbsd5.0"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "hppa"
-  CONFIG["host"] = "hppa-unknown-openbsd5.4"
-  CONFIG["build_os"] = "openbsd5.4"
+  CONFIG["host"] = "hppa-unknown-openbsd5.0"
+  CONFIG["build_os"] = "openbsd5.0"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "hppa"
-  CONFIG["build"] = "hppa-unknown-openbsd5.4"
-  CONFIG["TEENY"] = "7"
-  CONFIG["MINOR"] = "8"
-  CONFIG["MAJOR"] = "1"
+  CONFIG["build"] = "hppa-unknown-openbsd5.0"
+  CONFIG["RUBYW_BASE_NAME"] = "rubyw"
+  CONFIG["RUBY_BASE_NAME"] = "ruby"
+  CONFIG["RUBY_RELEASE_DATE"] = "2011-07-09"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "1.9.2"
+  CONFIG["BASERUBY"] = "echo executable host ruby is required.  use --with-baseruby option.; false"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
-  CONFIG["LIBS"] = "-lm "
+  CONFIG["LIBS"] = "-pthread -lm "
   CONFIG["ECHO_T"] = ""
   CONFIG["ECHO_N"] = "-n"
   CONFIG["ECHO_C"] = ""
@@ -132,7 +166,7 @@ module Config
   CONFIG["docdir"] = "$(datarootdir)/doc/$(PACKAGE)"
   CONFIG["oldincludedir"] = "/usr/include"
   CONFIG["includedir"] = "$(prefix)/include"
-  CONFIG["localstatedir"] = "$(DESTDIR)/var"
+  CONFIG["localstatedir"] = "$(prefix)/var"
   CONFIG["sharedstatedir"] = "$(prefix)/com"
   CONFIG["sysconfdir"] = "$(DESTDIR)/etc"
   CONFIG["datadir"] = "$(datarootdir)"
@@ -140,6 +174,7 @@ module Config
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
+  CONFIG["program_transform_name"] = "s&$$&19&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -149,8 +184,7 @@ module Config
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
-  CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
+  CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
@@ -159,26 +193,35 @@ module Config
   CONFIG["topdir"] = File.dirname(__FILE__)
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
-  def Config::expand(val, config = CONFIG)
-    val.gsub!(/\$\$|\$\(([^()]+)\)|\$\{([^{}]+)\}/) do |var|
+  def RbConfig::expand(val, config = CONFIG)
+    newval = val.gsub(/\$\$|\$\(([^()]+)\)|\$\{([^{}]+)\}/) {
+      var = $&
       if !(v = $1 || $2)
 	'$'
       elsif key = config[v = v[/\A[^:]+(?=(?::(.*?)=(.*))?\z)/]]
 	pat, sub = $1, $2
 	config[v] = false
-	Config::expand(key, config)
-	config[v] = key
+	config[v] = RbConfig::expand(key, config)
 	key = key.gsub(/#{Regexp.quote(pat)}(?=\s|\z)/n) {sub} if pat
 	key
       else
 	var
       end
-    end
+    }
+    val.replace(newval) unless newval == val
     val
   end
   CONFIG.each_value do |val|
-    Config::expand(val)
+    RbConfig::expand(val)
+  end
+
+  # returns the absolute pathname of the ruby command.
+  def RbConfig.ruby
+    File.join(
+      RbConfig::CONFIG["bindir"],
+      RbConfig::CONFIG["ruby_install_name"] + RbConfig::CONFIG["EXEEXT"]
+    )
   end
 end
-RbConfig = Config # compatibility for ruby-1.9
+Config = RbConfig # compatibility for ruby-1.8.4 and older.
 CROSS_COMPILING = nil unless defined? CROSS_COMPILING
